@@ -119,7 +119,7 @@ class AzureContainerInstancesOperator(BaseOperator):
                 )
     """
 
-    template_fields: Sequence[str] = ("name", "image", "command", "environment_variables")
+    template_fields: Sequence[str] = ("name", "image", "command", "environment_variables", "volumes")
     template_fields_renderers = {"command": "bash", "environment_variables": "json"}
 
     def __init__(
